pub struct PackingError { /* private fields */ }Expand description
A packing could not be found that satisfied all offsets
If the “dot2” feature is enabled, you can use the write_graph_viz method
on this error to dump a text representation of the graph to disk. You can
then use graphviz to convert this into an image. For example, to create
an SVG, you might use, dot -v -Tsvg failure.dot2 > failure.svg, where
‘failure.dot2’ is the path where you dumped the graph.
Implementations
Sourceimpl PackingError
impl PackingError
Sourcepub fn write_graph_viz(&self, path: impl AsRef<Path>) -> Result<()>
Available on crate feature dot2 only.
pub fn write_graph_viz(&self, path: impl AsRef<Path>) -> Result<()>
dot2 only.Write a graphviz file representing the failed packing to the provided path.
Has the same semantics as std::fs::write.