Function write_fonts::dump_table
source · Expand description
Attempt to serialize a table.
If the table is malformed, this will return an Err(ValidationReport),
otherwise it will return the bytes encoding the table.
Attempt to serialize a table.
If the table is malformed, this will return an Err(ValidationReport),
otherwise it will return the bytes encoding the table.