FromTableRef

Trait FromTableRef 

pub trait FromTableRef<T>: FromObjRef<T> {
    // Provided method
    fn from_table_ref(from: &T) -> Self { ... }
}
A trait for types that can fully resolve themselves.

This means that any offsets held in this type are resolved relative to the start of the table itself (and not some parent table)

Provided Methods

fn from_table_ref(from: &T) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl FromTableRef<NameString<'_>> for String

Source

impl<'a, T, U, O, const N: usize> FromTableRef<ArrayOfNullableOffsets<'a, U, O>> for Vec<NullableOffsetMarker<T, N>>
where T: FromObjRef<U> + Default, U: ReadArgs + FontReadWithArgs<'a>, U::Args: 'static, O: Scalar + Offset,

Source

impl<'a, T, U, O, const N: usize> FromTableRef<ArrayOfOffsets<'a, U, O>> for Vec<OffsetMarker<T, N>>
where T: FromTableRef<U> + Default, U: ReadArgs + FontReadWithArgs<'a>, U::Args: 'static, O: Scalar + Offset,

Source

impl<T: FromTableRef<U>, U> FromTableRef<Option<U>> for Option<T>

Source

fn from_table_ref(from: &Option<U>) -> Self

Implementors

Source

impl FromTableRef<BaseCoord<'_>> for BaseCoord

Source

impl FromTableRef<CmapSubtable<'_>> for CmapSubtable

Source

impl FromTableRef<ClipBox<'_>> for ClipBox

Source

impl FromTableRef<Paint<'_>> for Paint

Source

impl FromTableRef<CaretValue<'_>> for CaretValue

Source

impl FromTableRef<Glyph<'_>> for Glyph

Source

impl FromTableRef<AnchorTable<'_>> for AnchorTable

Source

impl FromTableRef<ExtensionSubtable<'_>> for write_fonts::tables::gpos::ExtensionSubtable

Source

impl FromTableRef<PairPos<'_>> for PairPos

Source

impl FromTableRef<PositionLookup<'_>> for PositionLookup

Source

impl FromTableRef<SinglePos<'_>> for SinglePos

Source

impl FromTableRef<ExtensionSubtable<'_>> for write_fonts::tables::gsub::ExtensionSubtable

Source

impl FromTableRef<SingleSubst<'_>> for SingleSubst

Source

impl FromTableRef<SubstitutionLookup<'_>> for SubstitutionLookup

Source

impl FromTableRef<Ift<'_>> for Ift

Available on crate feature ift only.
Source

impl FromTableRef<ChainedSequenceContext<'_>> for ChainedSequenceContext

Source

impl FromTableRef<ClassDef<'_>> for ClassDef

Source

impl FromTableRef<Condition<'_>> for Condition

Source

impl FromTableRef<CoverageTable<'_>> for CoverageTable

Source

impl FromTableRef<DeviceOrVariationIndex<'_>> for DeviceOrVariationIndex

Source

impl FromTableRef<FeatureParams<'_>> for FeatureParams

Source

impl FromTableRef<SequenceContext<'_>> for SequenceContext

Source

impl FromTableRef<Metadata<'_>> for Metadata

Source

impl FromTableRef<CustomCharset<'_>> for CustomCharset

Source

impl FromTableRef<FdSelect<'_>> for FdSelect

Source

impl FromTableRef<AxisValue<'_>> for AxisValue

Source

impl FromTableRef<DeltaSetIndexMap<'_>> for DeltaSetIndexMap

Source

impl FromTableRef<CompositeGlyph<'_>> for CompositeGlyph

Source

impl FromTableRef<SimpleGlyph<'_>> for SimpleGlyph

Source

impl<'a> FromTableRef<ChainedSequenceContext<'a>> for PositionChainContext

Source

impl<'a> FromTableRef<ChainedSequenceContext<'a>> for SubstitutionChainContext

Source

impl<'a> FromTableRef<SequenceContext<'a>> for PositionSequenceContext

Source

impl<'a> FromTableRef<SequenceContext<'a>> for SubstitutionSequenceContext

Source

impl<'a> FromTableRef<Avar<'a>> for Avar

Source

impl<'a> FromTableRef<Axis<'a>> for Axis

Source

impl<'a> FromTableRef<Base<'a>> for Base

Source

impl<'a> FromTableRef<BaseCoordFormat1<'a>> for BaseCoordFormat1

Source

impl<'a> FromTableRef<BaseCoordFormat2<'a>> for BaseCoordFormat2

Source

impl<'a> FromTableRef<BaseCoordFormat3<'a>> for BaseCoordFormat3

Source

impl<'a> FromTableRef<BaseScript<'a>> for BaseScript

Source

impl<'a> FromTableRef<BaseScriptList<'a>> for BaseScriptList

Source

impl<'a> FromTableRef<BaseTagList<'a>> for BaseTagList

Source

impl<'a> FromTableRef<BaseValues<'a>> for BaseValues

Source

impl<'a> FromTableRef<MinMax<'a>> for MinMax

Source

impl<'a> FromTableRef<Cmap0<'a>> for Cmap0

Source

impl<'a> FromTableRef<Cmap2<'a>> for Cmap2

Source

impl<'a> FromTableRef<Cmap4<'a>> for Cmap4

Source

impl<'a> FromTableRef<Cmap6<'a>> for Cmap6

Source

impl<'a> FromTableRef<Cmap8<'a>> for Cmap8

Source

impl<'a> FromTableRef<Cmap10<'a>> for Cmap10

Source

impl<'a> FromTableRef<Cmap12<'a>> for Cmap12

Source

impl<'a> FromTableRef<Cmap13<'a>> for Cmap13

Source

impl<'a> FromTableRef<Cmap14<'a>> for Cmap14

Source

impl<'a> FromTableRef<Cmap<'a>> for Cmap

Source

impl<'a> FromTableRef<DefaultUvs<'a>> for DefaultUvs

Source

impl<'a> FromTableRef<NonDefaultUvs<'a>> for NonDefaultUvs

Source

impl<'a> FromTableRef<Affine2x3<'a>> for Affine2x3

Source

impl<'a> FromTableRef<BaseGlyphList<'a>> for BaseGlyphList

Source

impl<'a> FromTableRef<ClipBoxFormat1<'a>> for ClipBoxFormat1

Source

impl<'a> FromTableRef<ClipBoxFormat2<'a>> for ClipBoxFormat2

Source

impl<'a> FromTableRef<ClipList<'a>> for ClipList

Source

impl<'a> FromTableRef<ColorLine<'a>> for ColorLine

Source

impl<'a> FromTableRef<Colr<'a>> for Colr

Source

impl<'a> FromTableRef<LayerList<'a>> for LayerList

Source

impl<'a> FromTableRef<PaintColrGlyph<'a>> for PaintColrGlyph

Source

impl<'a> FromTableRef<PaintColrLayers<'a>> for PaintColrLayers

Source

impl<'a> FromTableRef<PaintComposite<'a>> for PaintComposite

Source

impl<'a> FromTableRef<PaintGlyph<'a>> for PaintGlyph

Source

impl<'a> FromTableRef<PaintLinearGradient<'a>> for PaintLinearGradient

Source

impl<'a> FromTableRef<PaintRadialGradient<'a>> for PaintRadialGradient

Source

impl<'a> FromTableRef<PaintRotate<'a>> for PaintRotate

Source

impl<'a> FromTableRef<PaintRotateAroundCenter<'a>> for PaintRotateAroundCenter

Source

impl<'a> FromTableRef<PaintScale<'a>> for PaintScale

Source

impl<'a> FromTableRef<PaintScaleAroundCenter<'a>> for PaintScaleAroundCenter

Source

impl<'a> FromTableRef<PaintScaleUniform<'a>> for PaintScaleUniform

Source

impl<'a> FromTableRef<PaintScaleUniformAroundCenter<'a>> for PaintScaleUniformAroundCenter

Source

impl<'a> FromTableRef<PaintSkew<'a>> for PaintSkew

Source

impl<'a> FromTableRef<PaintSkewAroundCenter<'a>> for PaintSkewAroundCenter

Source

impl<'a> FromTableRef<PaintSolid<'a>> for PaintSolid

Source

impl<'a> FromTableRef<PaintSweepGradient<'a>> for PaintSweepGradient

Source

impl<'a> FromTableRef<PaintTransform<'a>> for PaintTransform

Source

impl<'a> FromTableRef<PaintTranslate<'a>> for PaintTranslate

Source

impl<'a> FromTableRef<PaintVarLinearGradient<'a>> for PaintVarLinearGradient

Source

impl<'a> FromTableRef<PaintVarRadialGradient<'a>> for PaintVarRadialGradient

Source

impl<'a> FromTableRef<PaintVarRotate<'a>> for PaintVarRotate

Source

impl<'a> FromTableRef<PaintVarRotateAroundCenter<'a>> for PaintVarRotateAroundCenter

Source

impl<'a> FromTableRef<PaintVarScale<'a>> for PaintVarScale

Source

impl<'a> FromTableRef<PaintVarScaleAroundCenter<'a>> for PaintVarScaleAroundCenter

Source

impl<'a> FromTableRef<PaintVarScaleUniform<'a>> for PaintVarScaleUniform

Source

impl<'a> FromTableRef<PaintVarScaleUniformAroundCenter<'a>> for PaintVarScaleUniformAroundCenter

Source

impl<'a> FromTableRef<PaintVarSkew<'a>> for PaintVarSkew

Source

impl<'a> FromTableRef<PaintVarSkewAroundCenter<'a>> for PaintVarSkewAroundCenter

Source

impl<'a> FromTableRef<PaintVarSolid<'a>> for PaintVarSolid

Source

impl<'a> FromTableRef<PaintVarSweepGradient<'a>> for PaintVarSweepGradient

Source

impl<'a> FromTableRef<PaintVarTransform<'a>> for PaintVarTransform

Source

impl<'a> FromTableRef<PaintVarTranslate<'a>> for PaintVarTranslate

Source

impl<'a> FromTableRef<VarAffine2x3<'a>> for VarAffine2x3

Source

impl<'a> FromTableRef<VarColorLine<'a>> for VarColorLine

Source

impl<'a> FromTableRef<Cpal<'a>> for Cpal

Source

impl<'a> FromTableRef<Dsig<'a>> for Dsig

Source

impl<'a> FromTableRef<SignatureBlockFormat1<'a>> for SignatureBlockFormat1

Source

impl<'a> FromTableRef<AxisInstanceArrays<'a>> for AxisInstanceArrays

Source

impl<'a> FromTableRef<Fvar<'a>> for Fvar

Source

impl<'a> FromTableRef<Gasp<'a>> for Gasp

Source

impl<'a> FromTableRef<AttachList<'a>> for AttachList

Source

impl<'a> FromTableRef<AttachPoint<'a>> for AttachPoint

Source

impl<'a> FromTableRef<CaretValueFormat1<'a>> for CaretValueFormat1

Source

impl<'a> FromTableRef<CaretValueFormat2<'a>> for CaretValueFormat2

Source

impl<'a> FromTableRef<CaretValueFormat3<'a>> for CaretValueFormat3

Source

impl<'a> FromTableRef<Gdef<'a>> for Gdef

Source

impl<'a> FromTableRef<LigCaretList<'a>> for LigCaretList

Source

impl<'a> FromTableRef<LigGlyph<'a>> for LigGlyph

Source

impl<'a> FromTableRef<MarkGlyphSets<'a>> for MarkGlyphSets

Source

impl<'a> FromTableRef<AnchorFormat1<'a>> for AnchorFormat1

Source

impl<'a> FromTableRef<AnchorFormat2<'a>> for AnchorFormat2

Source

impl<'a> FromTableRef<AnchorFormat3<'a>> for AnchorFormat3

Source

impl<'a> FromTableRef<BaseArray<'a>> for BaseArray

Source

impl<'a> FromTableRef<CursivePosFormat1<'a>> for CursivePosFormat1

Source

impl<'a> FromTableRef<Gpos<'a>> for Gpos

Source

impl<'a> FromTableRef<LigatureArray<'a>> for LigatureArray

Source

impl<'a> FromTableRef<LigatureAttach<'a>> for LigatureAttach

Source

impl<'a> FromTableRef<Mark2Array<'a>> for Mark2Array

Source

impl<'a> FromTableRef<MarkArray<'a>> for MarkArray

Source

impl<'a> FromTableRef<MarkBasePosFormat1<'a>> for MarkBasePosFormat1

Source

impl<'a> FromTableRef<MarkLigPosFormat1<'a>> for MarkLigPosFormat1

Source

impl<'a> FromTableRef<MarkMarkPosFormat1<'a>> for MarkMarkPosFormat1

Source

impl<'a> FromTableRef<PairPosFormat1<'a>> for PairPosFormat1

Source

impl<'a> FromTableRef<PairPosFormat2<'a>> for PairPosFormat2

Source

impl<'a> FromTableRef<PairSet<'a>> for PairSet

Source

impl<'a> FromTableRef<SinglePosFormat1<'a>> for SinglePosFormat1

Source

impl<'a> FromTableRef<SinglePosFormat2<'a>> for SinglePosFormat2

Source

impl<'a> FromTableRef<AlternateSet<'a>> for AlternateSet

Source

impl<'a> FromTableRef<AlternateSubstFormat1<'a>> for AlternateSubstFormat1

Source

impl<'a> FromTableRef<Gsub<'a>> for Gsub

Source

impl<'a> FromTableRef<Ligature<'a>> for Ligature

Source

impl<'a> FromTableRef<LigatureSet<'a>> for LigatureSet

Source

impl<'a> FromTableRef<LigatureSubstFormat1<'a>> for LigatureSubstFormat1

Source

impl<'a> FromTableRef<MultipleSubstFormat1<'a>> for MultipleSubstFormat1

Source

impl<'a> FromTableRef<ReverseChainSingleSubstFormat1<'a>> for ReverseChainSingleSubstFormat1

Source

impl<'a> FromTableRef<Sequence<'a>> for Sequence

Source

impl<'a> FromTableRef<SingleSubstFormat1<'a>> for SingleSubstFormat1

Source

impl<'a> FromTableRef<SingleSubstFormat2<'a>> for SingleSubstFormat2

Source

impl<'a> FromTableRef<SharedTuples<'a>> for SharedTuples

Source

impl<'a> FromTableRef<Head<'a>> for Head

Source

impl<'a> FromTableRef<Hhea<'a>> for Hhea

Source

impl<'a> FromTableRef<Hmtx<'a>> for Hmtx

Source

impl<'a> FromTableRef<Hvar<'a>> for Hvar

Source

impl<'a> FromTableRef<EntryData<'a>> for EntryData

Available on crate feature ift only.
Source

impl<'a> FromTableRef<FeatureMap<'a>> for FeatureMap

Available on crate feature ift only.
Source

impl<'a> FromTableRef<GlyphData<'a>> for write_fonts::tables::ift::GlyphData

Available on crate feature ift only.
Source

impl<'a> FromTableRef<GlyphKeyedPatch<'a>> for GlyphKeyedPatch

Available on crate feature ift only.
Source

impl<'a> FromTableRef<GlyphMap<'a>> for GlyphMap

Available on crate feature ift only.
Source

impl<'a> FromTableRef<GlyphPatches<'a>> for GlyphPatches

Available on crate feature ift only.
Source

impl<'a> FromTableRef<IdStringData<'a>> for IdStringData

Available on crate feature ift only.
Source

impl<'a> FromTableRef<MappingEntries<'a>> for MappingEntries

Available on crate feature ift only.
Source

impl<'a> FromTableRef<PatchMapFormat1<'a>> for PatchMapFormat1

Available on crate feature ift only.
Source

impl<'a> FromTableRef<PatchMapFormat2<'a>> for PatchMapFormat2

Available on crate feature ift only.
Source

impl<'a> FromTableRef<TableKeyedPatch<'a>> for TableKeyedPatch

Available on crate feature ift only.
Source

impl<'a> FromTableRef<TablePatch<'a>> for TablePatch

Available on crate feature ift only.
Source

impl<'a> FromTableRef<ChainedClassSequenceRule<'a>> for ChainedClassSequenceRule

Source

impl<'a> FromTableRef<ChainedClassSequenceRuleSet<'a>> for ChainedClassSequenceRuleSet

Source

impl<'a> FromTableRef<ChainedSequenceContextFormat1<'a>> for ChainedSequenceContextFormat1

Source

impl<'a> FromTableRef<ChainedSequenceContextFormat2<'a>> for ChainedSequenceContextFormat2

Source

impl<'a> FromTableRef<ChainedSequenceContextFormat3<'a>> for ChainedSequenceContextFormat3

Source

impl<'a> FromTableRef<ChainedSequenceRule<'a>> for ChainedSequenceRule

Source

impl<'a> FromTableRef<ChainedSequenceRuleSet<'a>> for ChainedSequenceRuleSet

Source

impl<'a> FromTableRef<CharacterVariantParams<'a>> for CharacterVariantParams

Source

impl<'a> FromTableRef<ClassDefFormat1<'a>> for ClassDefFormat1

Source

impl<'a> FromTableRef<ClassDefFormat2<'a>> for ClassDefFormat2

Source

impl<'a> FromTableRef<ClassSequenceRule<'a>> for ClassSequenceRule

Source

impl<'a> FromTableRef<ClassSequenceRuleSet<'a>> for ClassSequenceRuleSet

Source

impl<'a> FromTableRef<ConditionFormat1<'a>> for ConditionFormat1

Source

impl<'a> FromTableRef<ConditionFormat2<'a>> for ConditionFormat2

Source

impl<'a> FromTableRef<ConditionFormat3<'a>> for ConditionFormat3

Source

impl<'a> FromTableRef<ConditionFormat4<'a>> for ConditionFormat4

Source

impl<'a> FromTableRef<ConditionFormat5<'a>> for ConditionFormat5

Source

impl<'a> FromTableRef<ConditionSet<'a>> for ConditionSet

Source

impl<'a> FromTableRef<CoverageFormat1<'a>> for CoverageFormat1

Source

impl<'a> FromTableRef<CoverageFormat2<'a>> for CoverageFormat2

Source

impl<'a> FromTableRef<Device<'a>> for Device

Source

impl<'a> FromTableRef<Feature<'a>> for Feature

Source

impl<'a> FromTableRef<FeatureList<'a>> for FeatureList

Source

impl<'a> FromTableRef<FeatureTableSubstitution<'a>> for FeatureTableSubstitution

Source

impl<'a> FromTableRef<FeatureVariations<'a>> for FeatureVariations

Source

impl<'a> FromTableRef<LangSys<'a>> for LangSys

Source

impl<'a> FromTableRef<Script<'a>> for Script

Source

impl<'a> FromTableRef<ScriptList<'a>> for ScriptList

Source

impl<'a> FromTableRef<SequenceContextFormat1<'a>> for SequenceContextFormat1

Source

impl<'a> FromTableRef<SequenceContextFormat2<'a>> for SequenceContextFormat2

Source

impl<'a> FromTableRef<SequenceContextFormat3<'a>> for SequenceContextFormat3

Source

impl<'a> FromTableRef<SequenceRule<'a>> for SequenceRule

Source

impl<'a> FromTableRef<SequenceRuleSet<'a>> for SequenceRuleSet

Source

impl<'a> FromTableRef<SizeParams<'a>> for SizeParams

Source

impl<'a> FromTableRef<StylisticSetParams<'a>> for StylisticSetParams

Source

impl<'a> FromTableRef<VariationIndex<'a>> for VariationIndex

Source

impl<'a> FromTableRef<Maxp<'a>> for Maxp

Source

impl<'a> FromTableRef<Meta<'a>> for Meta

Source

impl<'a> FromTableRef<Mvar<'a>> for Mvar

Source

impl<'a> FromTableRef<Name<'a>> for Name

Source

impl<'a> FromTableRef<Os2<'a>> for Os2

Source

impl<'a> FromTableRef<Post<'a>> for Post

Source

impl<'a> FromTableRef<CharsetFormat0<'a>> for CharsetFormat0

Source

impl<'a> FromTableRef<CharsetFormat1<'a>> for CharsetFormat1

Source

impl<'a> FromTableRef<CharsetFormat2<'a>> for CharsetFormat2

Source

impl<'a> FromTableRef<FdSelectFormat0<'a>> for FdSelectFormat0

Source

impl<'a> FromTableRef<FdSelectFormat3<'a>> for FdSelectFormat3

Source

impl<'a> FromTableRef<FdSelectFormat4<'a>> for FdSelectFormat4

Source

impl<'a> FromTableRef<Index1<'a>> for Index1

Source

impl<'a> FromTableRef<Index2<'a>> for Index2

Source

impl<'a> FromTableRef<GlyphData<'a>> for write_fonts::tables::sbix::GlyphData

Source

impl<'a> FromTableRef<Sbix<'a>> for Sbix

Source

impl<'a> FromTableRef<Strike<'a>> for Strike

Source

impl<'a> FromTableRef<AxisValueArray<'a>> for AxisValueArray

Source

impl<'a> FromTableRef<AxisValueFormat1<'a>> for AxisValueFormat1

Source

impl<'a> FromTableRef<AxisValueFormat2<'a>> for AxisValueFormat2

Source

impl<'a> FromTableRef<AxisValueFormat3<'a>> for AxisValueFormat3

Source

impl<'a> FromTableRef<AxisValueFormat4<'a>> for AxisValueFormat4

Source

impl<'a> FromTableRef<Stat<'a>> for Stat

Source

impl<'a> FromTableRef<ConditionList<'a>> for ConditionList

Source

impl<'a> FromTableRef<MultiItemVariationData<'a>> for MultiItemVariationData

Source

impl<'a> FromTableRef<MultiItemVariationStore<'a>> for MultiItemVariationStore

Source

impl<'a> FromTableRef<SparseVariationRegion<'a>> for SparseVariationRegion

Source

impl<'a> FromTableRef<SparseVariationRegionList<'a>> for SparseVariationRegionList

Source

impl<'a> FromTableRef<Varc<'a>> for Varc

Source

impl<'a> FromTableRef<DeltaSetIndexMapFormat0<'a>> for DeltaSetIndexMapFormat0

Source

impl<'a> FromTableRef<DeltaSetIndexMapFormat1<'a>> for DeltaSetIndexMapFormat1

Source

impl<'a> FromTableRef<ItemVariationData<'a>> for ItemVariationData

Source

impl<'a> FromTableRef<ItemVariationStore<'a>> for ItemVariationStore

Source

impl<'a> FromTableRef<TupleVariationHeader<'a>> for TupleVariationHeader

Source

impl<'a> FromTableRef<VariationRegionList<'a>> for VariationRegionList

Source

impl<'a> FromTableRef<Vhea<'a>> for Vhea

Source

impl<'a> FromTableRef<Vmtx<'a>> for Vmtx

Source

impl<'a> FromTableRef<Vvar<'a>> for Vvar

Source

impl<'a, T, U> FromTableRef<ExtensionPosFormat1<'a, U>> for ExtensionPosFormat1<T>
where U: FontRead<'a>, T: FromTableRef<U> + Default + 'static,

Source

impl<'a, T, U> FromTableRef<ExtensionSubstFormat1<'a, U>> for ExtensionSubstFormat1<T>
where U: FontRead<'a>, T: FromTableRef<U> + Default + 'static,

Source

impl<'a, T, U> FromTableRef<Lookup<'a, U>> for Lookup<T>
where U: FontRead<'a>, T: FromTableRef<U> + Default + 'static,

Source

impl<'a, T, U> FromTableRef<LookupList<'a, U>> for LookupList<T>
where U: FontRead<'a>, T: FromTableRef<U> + Default + 'static,

Source

impl<T: FromTableRef<U> + Default, U, const N: usize> FromTableRef<Result<U, ReadError>> for OffsetMarker<T, N>

Source

impl<T: FromTableRef<U>, U, const N: usize> FromTableRef<Option<Result<U, ReadError>>> for NullableOffsetMarker<T, N>