pub trait ToOwnedObj<T> {
// Required method
fn to_owned_obj(&self, data: FontData<'_>) -> T;
}Available on crate feature
tables only.Expand description
A conversion from a parsed font object type to an owned version, resolving offsets.
You should avoid implementing this trait manually. Like std::convert::Into,
it is provided as a blanket impl when you implement FromObjRef<T>.
Required Methods
Sourcefn to_owned_obj(&self, data: FontData<'_>) -> T
fn to_owned_obj(&self, data: FontData<'_>) -> T
Convert this type into T, using the provided data to resolve any offsets.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".