pub trait ToOwnedTable<T>: ToOwnedObj<T> {
// Required method
fn to_owned_table(&self) -> T;
}Available on crate feature
tables only.Expand description
A conversion from a fully resolvable parsed font table to its owned equivalent.
As with ToOwnedObj, you should not need to implement this manually.
Required Methods
fn to_owned_table(&self) -> T
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".