Struct write_fonts::layout::CharacterVariantParams
source · [−]pub struct CharacterVariantParams {
pub feat_ui_label_name_id: u16,
pub feat_ui_tooltip_text_name_id: u16,
pub sample_text_name_id: u16,
pub num_named_parameters: u16,
pub first_param_ui_label_name_id: u16,
pub character: Vec<Uint24>,
}Expand description
featureParams for ‘cv01’-‘cv99’
Fields
feat_ui_label_name_id: u16The ‘name’ table name ID that specifies a string (or strings, for multiple languages) for a user-interface label for this feature. (May be NULL.)
feat_ui_tooltip_text_name_id: u16The ‘name’ table name ID that specifies a string (or strings, for multiple languages) that an application can use for tooltip text for this feature. (May be NULL.)
sample_text_name_id: u16The ‘name’ table name ID that specifies sample text that illustrates the effect of this feature. (May be NULL.)
num_named_parameters: u16Number of named parameters. (May be zero.)
first_param_ui_label_name_id: u16The first ‘name’ table name ID used to specify strings for user-interface labels for the feature parameters. (Must be zero if numParameters is zero.)
character: Vec<Uint24>The Unicode Scalar Value of the characters for which this feature provides glyph variants.