#[non_exhaustive]pub struct BuilderError {
pub tag: Tag,
pub inner: Error,
}Expand description
An error returned when attempting to add a table to the builder.
This wraps a compilation error, adding the tag of the table where it was encountered.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tag: TagThe tag of the root table where the error occurred
inner: ErrorThe underlying error