pub struct OffsetMarker<T, const N: usize = WIDTH_16> { /* private fields */ }
An offset subtable.

The generic const N is the width of the offset, in bytes.

Implementations

true if the offset is non-null

true if the offset is null

Get the object. Fonts in the wild may be malformed, so this still returns an option?

Create a new marker.

Creates a new marker with an object that may be null.