pub struct Cmap6 {
pub length: u16,
pub language: u16,
pub first_code: u16,
pub entry_count: u16,
pub glyph_id_array: Vec<u16>,
}Available on crate feature
tables only.Expand description
cmap Format 6: Trimmed table mapping
Fields
length: u16This is the length in bytes of the subtable.
language: u16For requirements on use of the language field, see “Use of the language field in ‘cmap’ subtables” in this document.
first_code: u16First character code of subrange.
entry_count: u16Number of character codes in subrange.
glyph_id_array: Vec<u16>Array of glyph index values for character codes in the range.
Implementations