Struct write_fonts::tables::cmap::CmapConflict
source · pub struct CmapConflict { /* private fields */ }Expand description
A conflicting Cmap definition, one char is mapped to multiple distinct GlyphIds.
If there are multiple conflicting mappings, one is chosen arbitrarily. gid1 is less than gid2.