pub enum GvarInputError {
UnexpectedAxisCount {
gid: GlyphId,
expected: u16,
actual: u16,
},
InconsistentGlyphAxisCount(GlyphId),
InconsistentDeltaLength(GlyphId),
InconsistentTupleLengths(GlyphId),
}Expand description
An error representing invalid input when building a gvar table
Variants
UnexpectedAxisCount
Glyph variations do not have the expected axis count
InconsistentGlyphAxisCount(GlyphId)
A single glyph contains variations with inconsistent axis counts
InconsistentDeltaLength(GlyphId)
A single glyph contains variations with different delta counts
InconsistentTupleLengths(GlyphId)
A variation in this glyph contains an intermediate region with a different length than the peak.