pub enum DeviceOrDeltas {
Device(Device),
Deltas(Vec<(VariationRegion, i16)>),
None,
}Available on crate feature
tables only.Expand description
Either a Device table or a set of deltas.
This stores deltas directly; during compilation, the deltas are bundled
into some ItemVariationStore, and referenced by a VariationIndex.
Variants
Implementations
Sourceimpl DeviceOrDeltas
impl DeviceOrDeltas
Sourcepub fn build(
self,
var_store: &mut VariationStoreBuilder,
) -> Option<DeviceOrVariationIndex>
pub fn build( self, var_store: &mut VariationStoreBuilder, ) -> Option<DeviceOrVariationIndex>
Compile the device or deltas into their final form.
In the case of a device, this generates a Device table; in the
case of deltas this adds them to the VariationStoreBuilder, and returns
a PendingVariationIndex that must be remapped after the builder is
finished, using the returned VariationIndexRemapping.