CoverageTableBuilder

Struct CoverageTableBuilder 

pub struct CoverageTableBuilder { /* private fields */ }
Available on crate feature tables only.
A builder for CoverageTable tables.

This will choose the best format based for the included glyphs.

Implementations

Source

impl CoverageTableBuilder

pub fn from_glyphs(glyphs: Vec<GlyphId16>) -> Self

Create a new builder from a vec of GlyphId.

pub fn add(&mut self, glyph: GlyphId16) -> u16

Add a GlyphId to this coverage table.

Returns the coverage index of the added glyph.

If the glyph already exists, this returns its current index.

pub fn build(self) -> CoverageTable

Convert this builder into the appropriate CoverageTable variant.