pub struct ChainedSequenceContextFormat2 {
    pub coverage: OffsetMarker<CoverageTable>,
    pub backtrack_class_def: OffsetMarker<ClassDef>,
    pub input_class_def: OffsetMarker<ClassDef>,
    pub lookahead_class_def: OffsetMarker<ClassDef>,
    pub chained_class_seq_rule_sets: Vec<NullableOffsetMarker<ChainedClassSequenceRuleSet>>,
}
Fields

coverage: OffsetMarker<CoverageTable>

Offset to Coverage table, from beginning of ChainedSequenceContextFormat2 table

backtrack_class_def: OffsetMarker<ClassDef>

Offset to ClassDef table containing backtrack sequence context, from beginning of ChainedSequenceContextFormat2 table

input_class_def: OffsetMarker<ClassDef>

Offset to ClassDef table containing input sequence context, from beginning of ChainedSequenceContextFormat2 table

lookahead_class_def: OffsetMarker<ClassDef>

Offset to ClassDef table containing lookahead sequence context, from beginning of ChainedSequenceContextFormat2 table

chained_class_seq_rule_sets: Vec<NullableOffsetMarker<ChainedClassSequenceRuleSet>>

Array of offsets to ChainedClassSequenceRuleSet tables, from beginning of ChainedSequenceContextFormat2 table (may be NULL)

Implementations

Construct a new ChainedSequenceContextFormat2