pub struct CoverageTableBuilder { /* private fields */ }
A builder for CoverageTable tables.

This will choose the best format based for the included glyphs.

Implementations

Create a new builder from a vec of GlyphId.

Add a GlyphId to this coverage table.

Returns the coverage index of the added glyph.

If the glyph already exists, this returns its current index.

Convert this builder into the appropriate CoverageTable variant.