pub struct LookupFlag(_);
The LookupFlag bit enumeration.

Implementations

Return new, empty flags

Construct a LookupFlag from a raw value, discarding invalid bits

Raw transmutation to u16.

This bit relates only to the correct processing of the cursive attachment lookup type (GPOS lookup type 3).

When this bit is set, the last glyph in a given sequence to which the cursive attachment lookup is applied, will be positioned on the baseline.

This bit relates only to the correct processing of the cursive attachment lookup type (GPOS lookup type 3).

When this bit is set, the last glyph in a given sequence to which the cursive attachment lookup is applied, will be positioned on the baseline.

If set, skips over base glyphs

If set, skips over base glyphs

If set, skips over ligatures

If set, skips over ligatures

If set, skips over all combining marks

If set, skips over all combining marks

If set, indicates that the lookup table structure is followed by a MarkFilteringSet field.

The layout engine skips over all mark glyphs not in the mark filtering set indicated.

If set, indicates that the lookup table structure is followed by a MarkFilteringSet field.

The layout engine skips over all mark glyphs not in the mark filtering set indicated.

If not zero, skips over all marks of attachment type different from specified.

If not zero, skips over all marks of attachment type different from specified.