pub trait LookupSubtable {
const TYPE: LookupType;
}Available on crate feature
tables only.Expand description
A utility trait for writing lookup tables.
This allows us to attach the numerical lookup type to the appropriate concrete types, so that we can write it as needed without passing it around.
Required Associated Constants
Sourceconst TYPE: LookupType
const TYPE: LookupType
The lookup type of this layout subtable.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".