pub trait LookupType {
    const TYPE: u16;
}
A utility trait for writing lookup tables.

This allows us to attach the numerical lookup type to the appropriate concrete types, so that we can write it as needed without passing it around.

Required Associated Constants

The lookup type of this layout subtable.

Implementors