pub struct Mvar {
pub version: MajorMinor,
pub value_record_size: u16,
pub value_record_count: u16,
pub item_variation_store: NullableOffsetMarker<ItemVariationStore>,
pub value_records: Vec<ValueRecord>,
}Available on crate feature
tables only.Expand description
The MVAR (Metrics Variations) table
Fields
version: MajorMinorMajor version number of the horizontal metrics variations table — set to 1. Minor version number of the horizontal metrics variations table — set to 0.
value_record_size: u16The size in bytes of each value record — must be greater than zero.
value_record_count: u16The number of value records — may be zero.
item_variation_store: NullableOffsetMarker<ItemVariationStore>Offset in bytes from the start of this table to the item variation store table. If valueRecordCount is zero, set to zero; if valueRecordCount is greater than zero, must be greater than zero.
value_records: Vec<ValueRecord>Array of value records that identify target items and the associated delta-set index for each. The valueTag records must be in binary order of their valueTag field.
Implementations
Sourceimpl Mvar
impl Mvar
Sourcepub fn new(
version: MajorMinor,
item_variation_store: Option<ItemVariationStore>,
value_records: Vec<ValueRecord>,
) -> Self
pub fn new( version: MajorMinor, item_variation_store: Option<ItemVariationStore>, value_records: Vec<ValueRecord>, ) -> Self
Construct a new MVAR table.