Struct write_fonts::tables::os2::Os2

source ·
pub struct Os2 {
Show 38 fields pub x_avg_char_width: i16, pub us_weight_class: u16, pub us_width_class: u16, pub fs_type: u16, pub y_subscript_x_size: i16, pub y_subscript_y_size: i16, pub y_subscript_x_offset: i16, pub y_subscript_y_offset: i16, pub y_superscript_x_size: i16, pub y_superscript_y_size: i16, pub y_superscript_x_offset: i16, pub y_superscript_y_offset: i16, pub y_strikeout_size: i16, pub y_strikeout_position: i16, pub s_family_class: i16, pub panose_10: [u8; 10], pub ul_unicode_range_1: u32, pub ul_unicode_range_2: u32, pub ul_unicode_range_3: u32, pub ul_unicode_range_4: u32, pub ach_vend_id: Tag, pub fs_selection: u16, pub us_first_char_index: u16, pub us_last_char_index: u16, pub s_typo_ascender: i16, pub s_typo_descender: i16, pub s_typo_line_gap: i16, pub us_win_ascent: u16, pub us_win_descent: u16, pub ul_code_page_range_1: Option<u32>, pub ul_code_page_range_2: Option<u32>, pub sx_height: Option<i16>, pub s_cap_height: Option<i16>, pub us_default_char: Option<u16>, pub us_break_char: Option<u16>, pub us_max_context: Option<u16>, pub us_lower_optical_point_size: Option<u16>, pub us_upper_optical_point_size: Option<u16>,
}
Fields

x_avg_char_width: i16

Average weighted escapement.

The Average Character Width parameter specifies the arithmetic average of the escapement (width) of all non-zero width glyphs in the font.

us_weight_class: u16

Weight class.

Indicates the visual weight (degree of blackness or thickness of strokes) of the characters in the font. Values from 1 to 1000 are valid.

us_width_class: u16

Width class.

Indicates a relative change from the normal aspect ratio (width to height ratio) as specified by a font designer for the glyphs in a font.

fs_type: u16

Type flags.

Indicates font embedding licensing rights for the font.

y_subscript_x_size: i16

The recommended horizontal size in font design units for subscripts for this font.

y_subscript_y_size: i16

The recommended vertical size in font design units for subscripts for this font.

y_subscript_x_offset: i16

The recommended horizontal offset in font design units for subscripts for this font.

y_subscript_y_offset: i16

The recommended vertical offset in font design units for subscripts for this font.

y_superscript_x_size: i16

The recommended horizontal size in font design units for superscripts for this font.

y_superscript_y_size: i16

The recommended vertical size in font design units for superscripts for this font.

y_superscript_x_offset: i16

The recommended horizontal offset in font design units for superscripts for this font.

y_superscript_y_offset: i16

The recommended vertical offset in font design units for superscripts for this font.

y_strikeout_size: i16

Thickness of the strikeout stroke in font design units.

y_strikeout_position: i16

The position of the top of the strikeout stroke relative to the baseline in font design units.

s_family_class: i16

Font-family class and subclass. This parameter is a classification of font-family design.

panose_10: [u8; 10]

PANOSE classification number.

Additional specifications are required for PANOSE to classify non-Latin character sets.

ul_unicode_range_1: u32

Unicode Character Range.

Unicode Character Range (bits 0-31).

ul_unicode_range_2: u32

Unicode Character Range (bits 32-63).

ul_unicode_range_3: u32

Unicode Character Range (bits 64-95).

ul_unicode_range_4: u32

Unicode Character Range (bits 96-127).

ach_vend_id: Tag

Font Vendor Identification.

The four-character identifier for the vendor of the given type face.

fs_selection: u16

Font selection flags.

Contains information concerning the nature of the font patterns.

us_first_char_index: u16

The minimum Unicode index (character code) in this font.

us_last_char_index: u16

The maximum Unicode index (character code) in this font.

s_typo_ascender: i16

The typographic ascender for this font.

s_typo_descender: i16

The typographic descender for this font.

s_typo_line_gap: i16

The typographic line gap for this font.

us_win_ascent: u16

The “Windows ascender” metric.

This should be used to specify the height above the baseline for a clipping region.

us_win_descent: u16

The “Windows descender” metric.

This should be used to specify the vertical extent below the baseline for a clipping region.

ul_code_page_range_1: Option<u32>

Code page character range bits 0-31.

ul_code_page_range_2: Option<u32>

Code page character range bits 32-63.

sx_height: Option<i16>

This metric specifies the distance between the baseline and the approximate height of non-ascending lowercase letters measured in FUnits.

s_cap_height: Option<i16>

This metric specifies the distance between the baseline and the approximate height of uppercase letters measured in FUnits.

us_default_char: Option<u16>

This is the Unicode code point, in UTF-16 encoding, of a character that can be used for a default glyph.

us_break_char: Option<u16>

his is the Unicode code point, in UTF-16 encoding, of a character that can be used as a default break character.

us_max_context: Option<u16>

This field is used for fonts with multiple optical styles.

us_lower_optical_point_size: Option<u16>

This field is used for fonts with multiple optical styles.

us_upper_optical_point_size: Option<u16>

This field is used for fonts with multiple optical styles.