Struct write_fonts::tables::post::Post

source ·
pub struct Post {
    pub version: Version16Dot16,
    pub italic_angle: Fixed,
    pub underline_position: FWord,
    pub underline_thickness: FWord,
    pub is_fixed_pitch: u32,
    pub min_mem_type42: u32,
    pub max_mem_type42: u32,
    pub min_mem_type1: u32,
    pub max_mem_type1: u32,
    pub num_glyphs: Option<u16>,
    pub glyph_name_index: Option<Vec<u16>>,
    pub string_data: Option<Vec<PString>>,
}
Fields

version: Version16Dot16

0x00010000 for version 1.0 0x00020000 for version 2.0 0x00025000 for version 2.5 (deprecated) 0x00030000 for version 3.0

italic_angle: Fixed

Italic angle in counter-clockwise degrees from the vertical. Zero for upright text, negative for text that leans to the right (forward).

underline_position: FWord

This is the suggested distance of the top of the underline from the baseline (negative values indicate below baseline). The PostScript definition of this FontInfo dictionary key (the y coordinate of the center of the stroke) is not used for historical reasons. The value of the PostScript key may be calculated by subtracting half the underlineThickness from the value of this field.

underline_thickness: FWord

Suggested values for the underline thickness. In general, the underline thickness should match the thickness of the underscore character (U+005F LOW LINE), and should also match the strikeout thickness, which is specified in the OS/2 table.

is_fixed_pitch: u32

Set to 0 if the font is proportionally spaced, non-zero if the font is not proportionally spaced (i.e. monospaced).

min_mem_type42: u32

Minimum memory usage when an OpenType font is downloaded.

max_mem_type42: u32

Maximum memory usage when an OpenType font is downloaded.

min_mem_type1: u32

Minimum memory usage when an OpenType font is downloaded as a Type 1 font.

max_mem_type1: u32

Maximum memory usage when an OpenType font is downloaded as a Type 1 font.

num_glyphs: Option<u16>

Number of glyphs (this should be the same as numGlyphs in ‘maxp’ table).

glyph_name_index: Option<Vec<u16>>

Array of indices into the string data. See below for details.

string_data: Option<Vec<PString>>

Storage for the string data.

Implementations

source

impl Post

Construct a new Post