pub struct AxisRecord {
    pub axis_tag: Tag,
    pub axis_name_id: u16,
    pub axis_ordering: u16,
}
Fields

axis_tag: Tag

A tag identifying the axis of design variation.

axis_name_id: u16

The name ID for entries in the ‘name’ table that provide a display string for this axis.

axis_ordering: u16

A value that applications can use to determine primary sorting of face names, or for ordering of labels when composing family or face names.

Implementations

Construct a new AxisRecord