pub struct AxisValueArray {
    pub axis_values: Vec<OffsetMarker<AxisValue>>,
}
An array of AxisValue tables.

Fields

axis_values: Vec<OffsetMarker<AxisValue>>

Array of offsets to axis value tables, in bytes from the start of the axis value offsets array.

Implementations

Construct a new AxisValueArray