Struct write_fonts::tables::stat::Stat

source ·
pub struct Stat {
    pub design_axes: OffsetMarker<Vec<AxisRecord>, WIDTH_32>,
    pub offset_to_axis_values: OffsetMarker<Vec<OffsetMarker<AxisValue>>, WIDTH_32>,
    pub elided_fallback_name_id: Option<u16>,
}
STAT (Style Attributes Table)

Fields

design_axes: OffsetMarker<Vec<AxisRecord>, WIDTH_32>

Offset in bytes from the beginning of the STAT table to the start of the design axes array. If designAxisCount is zero, set to zero; if designAxisCount is greater than zero, must be greater than zero.

offset_to_axis_values: OffsetMarker<Vec<OffsetMarker<AxisValue>>, WIDTH_32>

Offset in bytes from the beginning of the STAT table to the start of the design axes value offsets array. If axisValueCount is zero, set to zero; if axisValueCount is greater than zero, must be greater than zero.

elided_fallback_name_id: Option<u16>

Name ID used as fallback when projection of names into a particular font model produces a subfamily name containing only elidable elements.

Implementations

Construct a new Stat