pub struct VarcFlags { /* private fields */ }Expand description
Flags used in the VarcComponent byte stream
https://github.com/harfbuzz/boring-expansion-spec/blob/main/VARC.md#variable-component-flags
Implementations
Sourceimpl VarcFlags
impl VarcFlags
pub const RESET_UNSPECIFIED_AXES: VarcFlags
pub const HAVE_AXES: VarcFlags
pub const AXIS_VALUES_HAVE_VARIATION: VarcFlags
pub const TRANSFORM_HAS_VARIATION: VarcFlags
pub const HAVE_TRANSLATE_X: VarcFlags
pub const HAVE_TRANSLATE_Y: VarcFlags
pub const HAVE_ROTATION: VarcFlags
pub const HAVE_CONDITION: VarcFlags
pub const HAVE_SCALE_X: VarcFlags
pub const HAVE_SCALE_Y: VarcFlags
pub const HAVE_TCENTER_X: VarcFlags
pub const HAVE_TCENTER_Y: VarcFlags
pub const GID_IS_24BIT: VarcFlags
pub const HAVE_SKEW_X: VarcFlags
pub const HAVE_SKEW_Y: VarcFlags
pub const RESERVED_MASK: VarcFlags
Sourceimpl VarcFlags
impl VarcFlags
Sourcepub const fn from_bits(bits: u32) -> Option<VarcFlags>
pub const fn from_bits(bits: u32) -> Option<VarcFlags>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> VarcFlags
pub const fn from_bits_truncate(bits: u32) -> VarcFlags
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const fn intersects(&self, other: VarcFlags) -> bool
pub const fn intersects(&self, other: VarcFlags) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: VarcFlags) -> bool
pub const fn contains(&self, other: VarcFlags) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub const fn intersection(self, other: VarcFlags) -> VarcFlags
pub const fn intersection(self, other: VarcFlags) -> VarcFlags
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: VarcFlags) -> VarcFlags
pub const fn union(self, other: VarcFlags) -> VarcFlags
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both.
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: VarcFlags) -> VarcFlags
pub const fn difference(self, other: VarcFlags) -> VarcFlags
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.