Module common_builder

Module common_builder 

Common code for variation store builders.

Structs

VarStoreRemapping
A map from the temporary delta set identifiers to the final values.

Constants

NO_VARIATION_INDEX
The special index indicating no variation.

Traits

RemapVarStore
Remapping temporary delta set identifiers to the final values.