pub enum DeltaRunType {
Zero = 0,
I8 = 1,
I16 = 2,
I32 = 4,
}Available on crate feature
tables only.Expand description
The type of values for a given delta run (influences the number of bytes per delta)
The variants are intentionally set to the byte size of the type to allow usage as a multiplier when computing offsets.
Variants
Implementations
Sourceimpl DeltaRunType
impl DeltaRunType
Sourcepub fn new(control: u8) -> DeltaRunType
pub fn new(control: u8) -> DeltaRunType
The run type for a given control byte