MultiItemVariationStoreBuilder

Struct MultiItemVariationStoreBuilder 

pub struct MultiItemVariationStoreBuilder { /* private fields */ }
A builder for the MultiItemVariationStore

This handles assigning VariationIndex values to unique sets of tuple deltas and grouping delta sets into MultiItemVariationData subtables.

Implementations

Source

impl MultiItemVariationStoreBuilder

pub fn new() -> Self

Create a new builder.

pub fn is_empty(&self) -> bool

Returns true if no deltas have been added to this builder.

pub fn add_deltas<T: Into<i32>>( &mut self, deltas: Vec<(SparseRegion, Vec<T>)>, ) -> Result<u32, Error>

Add a set of tuple deltas and return a temporary ID.

Arguments
  • deltas - Vec of (SparseRegion, delta_tuple) pairs. Each delta_tuple must have the same length.
Returns

A temporary ID that can be used to retrieve the final VarIdx after calling build.

Returns an error if the delta tuples have inconsistent lengths.

pub fn build(self) -> (MultiItemVariationStore, MultiVariationIndexRemapping)

Build the MultiItemVariationStore table.

This also returns a structure that can be used to remap the temporarily assigned delta set IDs to their final VarIdx values.