pub struct SparseRegion(/* private fields */);Expand description
A sparse region definition, containing only axes with non-zero peaks.
This is used as a key for deduplicating regions in the builder. Each entry is (axis_index, start, peak, end).
Implementations