pub struct ItemVariationData {
    pub item_count: u16,
    pub word_delta_count: u16,
    pub region_indexes: Vec<u16>,
    pub delta_sets: Vec<u8>,
}
The ItemVariationData subtable

Fields

item_count: u16

The number of delta sets for distinct items.

word_delta_count: u16

A packed field: the high bit is a flag—see details below.

region_indexes: Vec<u16>

Array of indices into the variation region list for the regions referenced by this item variation data table.

delta_sets: Vec<u8>

Delta-set rows.

Implementations

Construct a new ItemVariationData