pub struct Vvar {
pub item_variation_store: OffsetMarker<ItemVariationStore, WIDTH_32>,
pub advance_height_mapping: NullableOffsetMarker<DeltaSetIndexMap, WIDTH_32>,
pub tsb_mapping: NullableOffsetMarker<DeltaSetIndexMap, WIDTH_32>,
pub bsb_mapping: NullableOffsetMarker<DeltaSetIndexMap, WIDTH_32>,
pub v_org_mapping: NullableOffsetMarker<DeltaSetIndexMap, WIDTH_32>,
}Available on crate feature
tables only.Expand description
The VVAR (Vertical Metrics Variations) table
Fields
item_variation_store: OffsetMarker<ItemVariationStore, WIDTH_32>Offset in bytes from the start of this table to the item variation store table.
advance_height_mapping: NullableOffsetMarker<DeltaSetIndexMap, WIDTH_32>Offset in bytes from the start of this table to the delta-set index mapping for advance heights (may be NULL).
tsb_mapping: NullableOffsetMarker<DeltaSetIndexMap, WIDTH_32>Offset in bytes from the start of this table to the delta-set index mapping for top side bearings (may be NULL).
bsb_mapping: NullableOffsetMarker<DeltaSetIndexMap, WIDTH_32>Offset in bytes from the start of this table to the delta-set index mapping for bottom side bearings (may be NULL).
v_org_mapping: NullableOffsetMarker<DeltaSetIndexMap, WIDTH_32>Offset in bytes from the start of this table to the delta-set index mapping for Y coordinates of vertical origins (may be NULL).
Implementations
Sourceimpl Vvar
impl Vvar
Sourcepub fn new(
item_variation_store: ItemVariationStore,
advance_height_mapping: Option<DeltaSetIndexMap>,
tsb_mapping: Option<DeltaSetIndexMap>,
bsb_mapping: Option<DeltaSetIndexMap>,
v_org_mapping: Option<DeltaSetIndexMap>,
) -> Self
pub fn new( item_variation_store: ItemVariationStore, advance_height_mapping: Option<DeltaSetIndexMap>, tsb_mapping: Option<DeltaSetIndexMap>, bsb_mapping: Option<DeltaSetIndexMap>, v_org_mapping: Option<DeltaSetIndexMap>, ) -> Self
Construct a new Vvar