pub trait FontWrite {
    fn write_into(&self, writer: &mut TableWriter);
}
A type that that can be written out as part of a font file.

This both handles writing big-endian bytes as well as describing the relationship between tables and their subtables.

Required Methods

Write our data and information about offsets into this TableWriter.

Implementations on Foreign Types

Implementors

source

impl FontWrite for Post