pub struct ValidationCtx { /* private fields */ }
A context for collecting validation error.

This is responsible for tracking the position in the tree at which a given error is reported.

paths/locations

As validation travels down through the object graph, the path is recorded via appropriate calls to methods like in_table and in_field.

Implementations

Run the provided closer in the context of a new table.

Errors reported in the closure will include the provided identifer in their path.

Run the provided closer in the context of a new field.

Errors reported in the closure will be associated with the field.

Run the provided closer in the context of an array.

Run the provided closer in the context of a new array item.

This must only be called in a closure passed to in_array.

Report a new error, associating it with the current path.