Struct write_fonts::OffsetMarker
source · [−]pub struct OffsetMarker<T, const N: usize = WIDTH_16> { /* private fields */ }Expand description
An offset subtable.
The generic const N is the width of the offset, in bytes.
Implementations
sourceimpl<const N: usize, T> OffsetMarker<T, N>
impl<const N: usize, T> OffsetMarker<T, N>
sourceimpl<const N: usize, T> OffsetMarker<T, N>
impl<const N: usize, T> OffsetMarker<T, N>
sourcepub fn new_maybe_null(obj: Option<T>) -> Self
pub fn new_maybe_null(obj: Option<T>) -> Self
Creates a new marker with an object that may be null.