pub type GvarInputError = TupleVariationStoreInputError<GlyphId>;Expand description
An error representing invalid input when building a gvar table
Aliased Type
pub enum GvarInputError {
UnexpectedAxisCount {
index: GlyphId,
expected: u16,
actual: u16,
},
InconsistentAxisCount(GlyphId),
InconsistentDeltaLength(GlyphId),
InconsistentTupleLengths(GlyphId),
}Variants
UnexpectedAxisCount
Glyph variations do not have the expected axis count
InconsistentAxisCount(GlyphId)
A single entry contains variations with inconsistent axis counts
InconsistentDeltaLength(GlyphId)
A single entry contains variations with different delta counts
InconsistentTupleLengths(GlyphId)
A variation in this entry contains an intermediate region with a different length than the peak.