Common code for variation store builders.
Structs
- VarStore
Remapping - A map from the temporary delta set identifiers to the final values.
Constants
- NO_
VARIATION_ INDEX - The special index indicating no variation.
Traits
- Remap
VarStore - Remapping temporary delta set identifiers to the final values.