pub trait RemapVarStore<T> {
// Required method
fn remap_variation_indices(&mut self, key_map: &VarStoreRemapping<T>);
}Expand description
Remapping temporary delta set identifiers to the final values.
This is called after the ItemVariationStore has been built, at which point any table containing a delta set index needs to be updated to point to the final value.
This trait should be implemented by any table that contains delta set indices, as well as for any of table containing such a table, which should recursively call it on the relevant subtables.
Required Methods
Sourcefn remap_variation_indices(&mut self, key_map: &VarStoreRemapping<T>)
fn remap_variation_indices(&mut self, key_map: &VarStoreRemapping<T>)
Remap any TemporaryDeltaSetIds to their final index values