Struct write_fonts::validate::ValidationCtx
source · [−]pub struct ValidationCtx { /* private fields */ }Expand description
A context for collecting validation error.
This is responsible for tracking the position in the tree at which a given error is reported.
paths/locations
As validation travels down through the object graph, the path is recorded via appropriate calls to methods like in_table and in_field.
Implementations
sourceimpl ValidationCtx
impl ValidationCtx
sourcepub fn in_table(&mut self, name: &'static str, f: impl FnOnce(&mut ValidationCtx))
pub fn in_table(&mut self, name: &'static str, f: impl FnOnce(&mut ValidationCtx))
Run the provided closer in the context of a new table.
Errors reported in the closure will include the provided identifer in their path.
sourcepub fn in_field(&mut self, name: &'static str, f: impl FnOnce(&mut ValidationCtx))
pub fn in_field(&mut self, name: &'static str, f: impl FnOnce(&mut ValidationCtx))
Run the provided closer in the context of a new field.
Errors reported in the closure will be associated with the field.
sourcepub fn in_array(&mut self, f: impl FnOnce(&mut ValidationCtx))
pub fn in_array(&mut self, f: impl FnOnce(&mut ValidationCtx))
Run the provided closer in the context of an array.
sourcepub fn array_item(&mut self, f: impl FnOnce(&mut ValidationCtx))
pub fn array_item(&mut self, f: impl FnOnce(&mut ValidationCtx))
Run the provided closer in the context of a new array item.
This must only be called in a closure passed to in_array.